summaryrefslogtreecommitdiff
path: root/lib/compiler/scripts
diff options
context:
space:
mode:
authorJohn Högberg <john@erlang.org>2019-09-27 10:39:03 +0200
committerJohn Högberg <john@erlang.org>2019-09-27 10:47:09 +0200
commite3a6a043a813be75e6e018df53216fb8993856aa (patch)
tree974a7d0f4d3837cb531426a8743c9c7ad35de691 /lib/compiler/scripts
parent70a3e70ce4fec9e5d79929aa28aecf4a81980322 (diff)
downloaderlang-e3a6a043a813be75e6e018df53216fb8993856aa.tar.gz
compiler: Fix broken dependencies in smoke test, and lock them
Diffstat (limited to 'lib/compiler/scripts')
-rw-r--r--lib/compiler/scripts/.gitignore6
-rw-r--r--lib/compiler/scripts/smoke-build/mix.lock9
-rw-r--r--lib/compiler/scripts/smoke-mix.exs8
3 files changed, 19 insertions, 4 deletions
diff --git a/lib/compiler/scripts/.gitignore b/lib/compiler/scripts/.gitignore
index 4e4eba766d..444b0cea1e 100644
--- a/lib/compiler/scripts/.gitignore
+++ b/lib/compiler/scripts/.gitignore
@@ -1 +1,5 @@
-/smoke-build
+/smoke-build/*
+
+# The dependency lock file must be kept to ensure that the smoke
+# test won't be broken as time passes.
+!/smoke-build/mix.lock
diff --git a/lib/compiler/scripts/smoke-build/mix.lock b/lib/compiler/scripts/smoke-build/mix.lock
new file mode 100644
index 0000000000..9fb83798c4
--- /dev/null
+++ b/lib/compiler/scripts/smoke-build/mix.lock
@@ -0,0 +1,9 @@
+%{
+ "credentials_obfuscation": {:hex, :credentials_obfuscation, "1.1.0", "513793cc20c18afc9e03e584b436192a751a8344890e03a8741c65c8d6866fab", [:rebar3], [], "hexpm"},
+ "goldrush": {:hex, :goldrush, "0.1.9", "f06e5d5f1277da5c413e84d5a2924174182fb108dabb39d5ec548b27424cd106", [:rebar3], [], "hexpm"},
+ "jsx": {:hex, :jsx, "2.9.0", "d2f6e5f069c00266cad52fb15d87c428579ea4d7d73a33669e12679e203329dd", [:mix, :rebar3], [], "hexpm"},
+ "lager": {:hex, :lager, "3.8.0", "3402b9a7e473680ca179fc2f1d827cab88dd37dd1e6113090c6f45ef05228a1c", [:rebar3], [{:goldrush, "0.1.9", [hex: :goldrush, repo: "hexpm", optional: false]}], "hexpm"},
+ "rabbit_common": {:hex, :rabbit_common, "3.7.18", "4249efdf1fd96a81739ffad675582f980cc55aa0a02217e4907b4cd719c44822", [:make, :rebar3], [{:credentials_obfuscation, "1.1.0", [hex: :credentials_obfuscation, repo: "hexpm", optional: false]}, {:jsx, "2.9.0", [hex: :jsx, repo: "hexpm", optional: false]}, {:lager, "3.8.0", [hex: :lager, repo: "hexpm", optional: false]}, {:ranch, "1.7.1", [hex: :ranch, repo: "hexpm", optional: false]}, {:recon, "2.5.0", [hex: :recon, repo: "hexpm", optional: false]}], "hexpm"},
+ "ranch": {:hex, :ranch, "1.7.1", "6b1fab51b49196860b733a49c07604465a47bdb78aa10c1c16a3d199f7f8c881", [:rebar3], [], "hexpm"},
+ "recon": {:hex, :recon, "2.5.0", "2f7fcbec2c35034bade2f9717f77059dc54eb4e929a3049ca7ba6775c0bd66cd", [:mix, :rebar3], [], "hexpm"},
+}
diff --git a/lib/compiler/scripts/smoke-mix.exs b/lib/compiler/scripts/smoke-mix.exs
index ba0815e465..0bfb80b53c 100644
--- a/lib/compiler/scripts/smoke-mix.exs
+++ b/lib/compiler/scripts/smoke-mix.exs
@@ -45,6 +45,7 @@ defmodule Smoke.MixProject do
{:gpb, "~> 4.6"},
{:gproc, "~> 0.8.0"},
{:graphql, "~> 0.15.0", hex: :graphql_erl},
+ {:hut, "~> 1.3"},
{:hackney, "~> 1.15.0"},
{:ibrowse, "~> 4.4.1"},
{:jose, "~> 1.9.0"},
@@ -89,12 +90,13 @@ defmodule Smoke.MixProject do
defp build_wings do
# If the Erlang system is not installed, the build will
# crash in plugins_src/accel when attempting to build
# the accel driver. Since there is very little Erlang code in
# the directory, skip the entire directory.
"""
echo "all:\n\t" >plugins_src/accel/Makefile
+ echo "all:\n\t" >c_src/Makefile
git commit -a -m'Disable for smoke testing'
git tag -a -m'Smoke test' vsmoke_test
make
@@ -89,12 +90,13 @@ defmodule Smoke.MixProject do
defp build_wings do
# If the Erlang system is not installed, the build will
- # crash in plugins_src/accel when attempting to build
- # the accel driver. Since there is very little Erlang code in
- # the directory, skip the entire directory.
+ # crash in c_src or plugins_src/accel when attempting to
+ # build native code. Since there is very little Erlang
+ # code in these directories, skip them both.
"""
echo "all:\n\t" >plugins_src/accel/Makefile